@@ -1,10 +1,4 @@
 
-try:
-    from collections import OrderedDict as odict
-except ImportError:
-    odict = dict
-    
-
 class listPipeline(object):
     def __init__(self):
         self.clear()
@@ -22,9 +16,4 @@ class listPipeline(object):
     def __len__(self):
         return len(self.back) + len(self.front)
     
-
-class mapPipeline(odict):
     
-    def items3(self):
-        for s,v in self.iteritems():
-            yield s,v[0],v[1]
\ No newline at end of file
